/*
  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
  dedicated to making software imaging solutions freely available.
  
  You may not use this file except in compliance with the License.
  obtain a copy of the License at
  
    http://www.imagemagick.org/script/license.php
  
  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.

  ImageMagick image paint methods.
*/
#ifndef _MAGICK_PAINT_H
#define _MAGICK_PAINT_H

#if defined(__cplusplus) || defined(c_plusplus)
extern "C" {
#endif

#include "magick/color.h"
#include "magick/draw.h"

extern MagickExport MagickBooleanType
  ColorFloodfillImage(Image *,const DrawInfo *,const PixelPacket,const long,
    const long,const PaintMethod),
  MatteFloodfillImage(Image *,const PixelPacket,const Quantum,const long,
    const long,const PaintMethod),
  PaintOpaqueImage(Image *,const MagickPixelPacket *,const MagickPixelPacket *),
  PaintTransparentImage(Image *,const MagickPixelPacket *,const Quantum);

#if defined(__cplusplus) || defined(c_plusplus)
}
#endif

#endif
